@@ -117,8 +117,9 @@ class Request(object):
             
     @cache_property
     def ip(self):
-        return self.environ.get('HTTP_X_FORWARDED_FOR', self.environ.get(
+        ret = self.environ.get('HTTP_X_FORWARDED_FOR', self.environ.get(
             'HTTP_X_REAL_IP', self.environ.get('REMOTE_ADDR')))
+        return ret.split(',')[0].strip() if ret and ',' in ret else ret
 
     @cache_property
     def referer(self):
